@@ -12,20 +12,24 @@
 #' # "popPopCov" and "popIndCov"
 #' 
 #' # See http://rsmlx.webpopix.org/userguide/newconnectors/ for more detailed examples
-#' # Download the demo examples here: http://rsmlx.webpopix.org/Rsmlx/Rsmlx10_demos.zip
+#' # Download the demo examples here: http://rsmlx.webpopix.org/installation
+
 #' }
 #' @export
 getEstimatedIndividualParameters2 <- function() {
   
-  ind.param <- getEstimatedIndividualParameters()
+  if (!initRsmlx())
+    return()
+  
+  ind.param <- mlx.getEstimatedIndividualParameters()
   N <- nrow(ind.param$saem)
-  pop.param <- getEstimatedPopulationParameters()
+  pop.param <- mlx.getEstimatedPopulationParameters()
   pop.param <- pop.param[grep("_pop",names(pop.param))]
   df <- as.data.frame(matrix(pop.param,nrow=N,ncol=length(pop.param),byrow=TRUE))
   names(df) <- gsub("_pop","",names(pop.param))
   ind.param$popPopCov <- data.frame(id=ind.param$saem["id"],df)
   
-  rand.eff <- getEstimatedRandomEffects()
+  rand.eff <- mlx.getEstimatedRandomEffects()
   
   if (!is.null(ind.param$conditionalMean)) {
     ip <- ind.param$conditionalMean
@@ -36,7 +40,7 @@ getEstimatedIndividualParameters2 <- function() {
   } else
     stop("The conditional mean or the conditional model should have been computed", call.=FALSE)
   
-  ind.dist <- getIndividualParameterModel()$distribution
+  ind.dist <- mlx.getIndividualParameterModel()$distribution
   var.param <- names(ind.dist)
   ind.param$popIndCov <- ind.param$popPopCov
   for (nj in var.param) {
@@ -44,7 +48,7 @@ getEstimatedIndividualParameters2 <- function() {
     yj <- ip[[nj]]
     rj <- re[[paste0("eta_",nj)]]
     if (dj == "normal") {
-      yjc <- exp(log(yj)-rj)
+      yjc <- yj-rj
     } else if (dj == "lognormal") {
       yjc <- exp(log(yj)-rj)
     } else if (dj == "logitnormal") {
@@ -70,14 +74,18 @@ getEstimatedIndividualParameters2 <- function() {
 #' r = getEstimatedPredictions() # r is a list with elements "y1" and "y2"
 #' 
 #' # See http://rsmlx.webpopix.org/userguide/newconnectors/ for more detailed examples
-#' # Download the demo examples here: http://rsmlx.webpopix.org/Rsmlx/Rsmlx10_demos.zip
+#' # Download the demo examples here: http://rsmlx.webpopix.org/installation
+
 #' }
 #' @export
 getEstimatedPredictions <- function() {
   
+  if (!initRsmlx())
+    return()
+  
   ip <- getEstimatedIndividualParameters2()
   
-  obs.info <- getObservationInformation()
+  obs.info <- mlx.getObservationInformation()
   
   df <- list()
   nout <- length(obs.info$name)
@@ -86,17 +94,17 @@ getEstimatedPredictions <- function() {
     df[[j]][obs.info$name[j]] <- NULL
   }
   
-  f.pop1 <- computePredictions(ip$popPopCov)
+  f.pop1 <- mlx.computePredictions(ip$popPopCov)
   for (j in 1:nout) {df[[j]]$popPopCov <- f.pop1[[j]]}
-  f.pop2 <- computePredictions(ip$popIndCov)
+  f.pop2 <- mlx.computePredictions(ip$popIndCov)
   for (j in 1:nout) {df[[j]]$popIndCov <- f.pop2[[j]]}
   
   if (!is.null(ip$conditionalMean)) {
-    f.mean <- computePredictions(ip$conditionalMean)
+    f.mean <- mlx.computePredictions(ip$conditionalMean)
     for (j in 1:nout) {df[[j]]$conditionalMean <- f.mean[[j]]}
   }
   if (!is.null(ip$conditionalMode)) {
-    f.mode <- computePredictions(ip$conditionalMode)
+    f.mode <- mlx.computePredictions(ip$conditionalMode)
     for (j in 1:nout) {df[[j]]$conditionalMode <- f.mode[[j]]}
   }
   names(df) <- names(f.pop1)
@@ -116,20 +124,24 @@ getEstimatedPredictions <- function() {
 #' r = getEstimatedResiduals()  # r is a list with elements "y1" and "y2" 
 #' 
 #' # See http://rsmlx.webpopix.org/userguide/newconnectors/ for more detailed examples
-#' # Download the demo examples here: http://rsmlx.webpopix.org/Rsmlx/Rsmlx10_demos.zip
+#' # Download the demo examples here: http://rsmlx.webpopix.org/installation
+
 #' }
 #' @export
 getEstimatedResiduals <- function() {
   
+  if (!initRsmlx())
+    return()
+  
   df=getEstimatedPredictions()
-  obs.info <- getObservationInformation()
+  obs.info <- mlx.getObservationInformation()
   nip <- c("popPopCov", "popIndCov", "conditionalMean", "conditionalMode")
   
   nout <- length(obs.info$name)
-  error.model <- getContinuousObservationModel()$errorModel
-  error.dist <- getContinuousObservationModel()$distribution
+  error.model <- mlx.getContinuousObservationModel()$errorModel
+  error.dist <- mlx.getContinuousObservationModel()$distribution
   ep <- error.parameter()
-  pop.param <- getEstimatedPopulationParameters()
+  pop.param <- mlx.getEstimatedPopulationParameters()
   param.error <- list()
   for (j in 1:nout) {
     dfj <- df[[j]]
@@ -143,7 +155,7 @@ getEstimatedResiduals <- function() {
       ypj <- log(dfj[,ij])
       yoj <- log(yoj)
     } else if (erj=="logitnormal") {
-      limiti <- getContinuousObservationModel()$limits[[names(error.dist)[j]]]
+      limiti <- mlx.getContinuousObservationModel()$limits[[names(error.dist)[j]]]
       ypj <- log((dfj[,ij]-limiti[1])/(limiti[2]-dfj[,ij]))
       yoj <- log((yoj-limiti[1])/(limiti[2]-yoj))
     }
@@ -179,20 +191,24 @@ getEstimatedResiduals <- function() {
 #' r = getSimulatedPredictions()  # r is a list with elements "Cc" and "E" 
 #' 
 #' # See http://rsmlx.webpopix.org/userguide/newconnectors/ for more detailed examples
-#' # Download the demo examples here: http://rsmlx.webpopix.org/Rsmlx/Rsmlx10_demos.zip
+#' # Download the demo examples here: http://rsmlx.webpopix.org/installation
+
 #' }
 #' @export
 getSimulatedPredictions <- function() {
   
-  sip <- getSimulatedIndividualParameters()
+  if (!initRsmlx())
+    return()
+  
+  sip <- mlx.getSimulatedIndividualParameters()
   if (is.null(sip$rep)) 
     sip$rep <- 1
   nrep <- max(sip$rep)
   
-  obs.info <- getObservationInformation()
+  obs.info <- mlx.getObservationInformation()
   df <- list()
   nout <- length(obs.info$name)
-  pred <- getContinuousObservationModel()$prediction
+  pred <- mlx.getContinuousObservationModel()$prediction
   for (j in 1:nout) {
     df[j] <- obs.info[obs.info$name[j]]
     df[[j]][obs.info$name[j]] <- NULL
@@ -204,7 +220,7 @@ getSimulatedPredictions <- function() {
   res <- list()
   for (irep in (1:nrep)) {
     parami <- subset(sip, rep==irep)[,col.el]
-    fi <- computePredictions(parami)
+    fi <- mlx.computePredictions(parami)
     for (j in 1:nout) {
       df[[j]][pred[j]] <- fi[[j]]
       df[[j]]["rep"] <- irep
@@ -231,19 +247,23 @@ getSimulatedPredictions <- function() {
 #' r = getSimulatedResiduals()  # r is a list with elements "y1" and "y2" 
 #' 
 #' # See http://rsmlx.webpopix.org/userguide/newconnectors/ for more detailed examples
-#' # Download the demo examples here: http://rsmlx.webpopix.org/Rsmlx/Rsmlx10_demos.zip
+#' # Download the demo examples here: http://rsmlx.webpopix.org/installation
+
 #' }
 #' @export
 getSimulatedResiduals <- function() {
   
+  if (!initRsmlx())
+    return()
+  
   df=getSimulatedPredictions()
-  obs.info <- getObservationInformation()
-
+  obs.info <- mlx.getObservationInformation()
+  
   nout <- length(obs.info$name)
-  error.model <- getContinuousObservationModel()$errorModel
-  error.dist <- getContinuousObservationModel()$distribution
+  error.model <- mlx.getContinuousObservationModel()$errorModel
+  error.dist <- mlx.getContinuousObservationModel()$distribution
   ep <- error.parameter()
-  pop.param <- getEstimatedPopulationParameters()
+  pop.param <- mlx.getEstimatedPopulationParameters()
   param.error <- list()
   nrep <- max(df[[1]]["rep"])
   for (j in 1:nout) {
@@ -258,7 +278,7 @@ getSimulatedResiduals <- function() {
       ypj <- log(dfj[,ij])
       yoj <- log(yoj)
     } else if (erj=="logitnormal") {
-      limiti <- getContinuousObservationModel()$limits[[names(error.dist)[j]]]
+      limiti <- mlx.getContinuousObservationModel()$limits[[names(error.dist)[j]]]
       ypj <- log((dfj[,ij]-limiti[1])/(limiti[2]-dfj[,ij]))
       yoj <- log((yoj-limiti[1])/(limiti[2]-yoj))
     }
@@ -294,11 +314,16 @@ getSimulatedResiduals <- function() {
 #' r = GetEstimatedCovarianceMatrix()  # r is a list with elements "cor.matrix" and "cov.matrix"
 #' 
 #' # See http://rsmlx.webpopix.org/userguide/newconnectors/ for more detailed examples
-#' # Download the demo examples here: http://rsmlx.webpopix.org/Rsmlx/Rsmlx10_demos.zip
+#' # Download the demo examples here: http://rsmlx.webpopix.org/installation
+
 #' }
 #' @export
-GetEstimatedCovarianceMatrix <- function() {
-  param <- getEstimatedPopulationParameters()
+getEstimatedCovarianceMatrix <- function() {
+  
+  if (!initRsmlx())
+    return()
+  
+  param <- mlx.getEstimatedPopulationParameters()
   pname <- names(param)
   i.omega <- grep("^omega_",pname)
   if (length(i.omega)>0) {
@@ -316,10 +341,12 @@ GetEstimatedCovarianceMatrix <- function() {
   c <- param[i.corr]
   R <- diag(rep(1,d))
   rownames(R) <- colnames(R) <- oname
-  for (j in 1:length(c)) {
-    cj <- names(c)[j]
-    sj <- strsplit(cj,"_")[[1]]
-    R[sj[3],sj[2]] <- R[sj[2],sj[3]] <- c[j]
+  if (length(c)>0) {
+    for (j in 1:length(c)) {
+      cj <- names(c)[j]
+      sj <- strsplit(cj,"_")[[1]]
+      R[sj[3],sj[2]] <- R[sj[2],sj[3]] <- c[j]
+    }
   }
   C <- diag(omega)%*%R%*%diag(omega)
   return(list(cor.matrix=R, cov.matrix=C))
@@ -328,10 +355,10 @@ GetEstimatedCovarianceMatrix <- function() {
 #--------------------------------------------------------------------
 error.parameter <- function(project=NULL) {
   if (is.null(project)) {
-    dp <- getProjectSettings()$directory
+    dp <- mlx.getProjectSettings()$directory
     if (!is.null(dp))
-    project <- paste0(dp,".mlxtran")
-#    project <- paste0(basename(dp),".mlxtran")
+      project <- paste0(dp,".mlxtran")
+    #    project <- paste0(basename(dp),".mlxtran")
   }
   if (!file.exists(project)) 
     stop("Enter a valid project", call.=FALSE)
@@ -354,93 +381,3 @@ error.parameter <- function(project=NULL) {
 }
 
 
-prcheck <- function(project, f=NULL, settings=NULL, model=NULL, paramToUse=NULL,
-                    parameters=NULL, level=NULL, tests=NULL, nboot=NULL, method=NULL) {
-  #prcheck <- function(project) {
-  if (identical(substr(project,1,9),"RsmlxDemo")) {
-    RsmlxDemo1.project <- RsmlxDemo2.project <- warfarin.data  <- resMonolix <- NULL
-    rm(RsmlxDemo1.project, RsmlxDemo2.project, warfarin.data, resMonolix)
-    eval(parse(text="data(RsmlxDemo)"))
-    tmp.dir <- tempdir()
-    write(RsmlxDemo1.project, file=file.path(tmp.dir,"RsmlxDemo1.mlxtran"))
-    write(RsmlxDemo2.project, file=file.path(tmp.dir,"RsmlxDemo2.mlxtran"))
-    write.csv(warfarin.data, file=file.path(tmp.dir,"warfarin_data.csv"), quote=FALSE, row.names = FALSE)
-    project <- file.path(tmp.dir,project)
-    demo <- TRUE
-    if (!is.null(f)) {
-      if (f=="boot") {
-        if (is.null(settings))
-          res <- resMonolix$r1.boot
-        else if (!is.null(settings$N) & is.null(settings$covStrat))
-          res <- resMonolix$r2.boot
-        else
-          res <- resMonolix$r3.boot
-      } else if (f=="build") {
-        if (identical(model,"all") & identical(paramToUse,"all")) 
-          res <- resMonolix$r1.build
-        else if (identical(model,"all")) 
-          res <- resMonolix$r2.build
-        else 
-          res <- resMonolix$r3.build
-      } else if (f=="conf") {
-        if (method == "fim" & level==0.90)
-          res <- resMonolix$r1.conf
-        else if (method == "fim" & level==0.95)
-          res <- resMonolix$r2.conf
-        else if (method == "proflike")
-          res <- resMonolix$r3.conf
-        else
-          res <- resMonolix$r4.conf
-      } else if (f=="cov") {
-        if (identical(method,"COSSAC") & identical(paramToUse,"all")) 
-          res <- resMonolix$r1.cov
-        else if (identical(method,"SCM")) 
-          res <- resMonolix$r2.cov
-        else 
-          res <- resMonolix$r3.cov
-      } else if (f=="test") {
-        if (length(tests)==4) 
-          res <- resMonolix$r1.test
-        else 
-          res <- resMonolix$r2.test
-      } else if (f=="set")
-        res="foo"
-    }
-    
-  } else {
-    
-    if (!grepl("\\.",project))
-      project <- paste0(project,".mlxtran")
-    
-    if(!file.exists(project))
-      stop(paste0("Project '", project, "' does not exist"), call.=FALSE)
-    
-    lp <- loadProject(project) 
-    if (!lp) 
-      stop(paste0("Could not load project '", project, "'"), call.=FALSE)
-    
-    demo <- FALSE
-    res <- NULL
-  }
-  
-  return(list(project=project, demo=demo, res=res))
-  #  return(project)
-}
-
-# prepare.demo <- function() {
-#   setwd("F:/modelBuilding/git/Rsmlx/inst/extdata")
-#   con = file("RsmlxDemo1.mlxtran", open = "r")
-#   RsmlxDemo1.project = readLines(con, warn=FALSE)
-#   close(con)
-#   con = file("RsmlxDemo2.mlxtran", open = "r")
-#   RsmlxDemo2.project = readLines(con, warn=FALSE)
-#   close(con)
-#   warfarin.data <- read.csv(file="warfarin_data.csv")
-#   setwd("F:/modelBuilding/git/Rsmlx/data")
-#   save(RsmlxDemo1.project, RsmlxDemo2.project, warfarin.data, file="RsmlxDemo.RData" )
-# }
-
-
-
-
-
